Ocyan plugin Wagtail Oscar integration
======================================

About Wagtail Oscar integration
-------------------------------
Ocyan plugin: Wagtail Oscar integration

Installation
------------
Add `ocyan.plugin.wagtail_oscar_integration` to your projects dependencies.

Building static
---------------
nvm use
npm install
make css
